@@ -2,18 +2,18 @@ package Path::Dispatcher::Rule::Chain;
 use Any::Moose;
 extends 'Path::Dispatcher::Rule::Always';
 
-override block => sub {
-    my $self  = shift;
-    my $block = super;
+override payload => sub {
+    my $self    = shift;
+    my $payload = super;
 
     if (!@_) {
         return sub {
-            $block->(@_);
+            $payload->(@_);
             die "Path::Dispatcher next rule\n"; # FIXME From Path::Dispatcher::Declarative... maybe this should go in a common place?
         };
     }
 
-    return $block;
+    return $payload;
 };
 
 __PACKAGE__->meta->make_immutable;
